
# Slot: may_have_singletons


Whether the graph may be expected to have singleton nodes. If it is said that it surely DOES NOT have any, it will allow for some speedups and lower mempry peaks.

URI: [https://w3id.org/neat/ensmallenRunConfig__may_have_singletons](https://w3id.org/neat/ensmallenRunConfig__may_have_singletons)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
